# rmtoo-art-xml-ganttproject2

NAME
DESCRIPTION
CONFIGURATION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-xml-ganttproject2 - requirements management tool: ganttproject

## DESCRIPTION

The rmtoo requirement manangement tool is able to output XML files which can be read in by GanttProject.

The requirements are structured by topics. The topic structure is used to build up to build up the project plan. Each requirement is a separate own task. Requirement dependencies are used to create the dependencies between tasks.

## CONFIGURATION

The name must be set to ganttproject2. The following parameters must be included in the map:

output_filename The parameter is the name of the file where the information will be stored.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010-2011 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later